=================
django-excel-base
=================

Django Excel Base

Installation
============

::

    pip install django-excel-base


Usage
=====

::

    from django_excel_base import as_xls, as_csv

